Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1473)

Unified Diff: chrome/browser/views/browser_actions_container.h

Issue 3076001: Cleanup: Remove pointless GetInsets() override. Simplify |container_size_| t... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/views/browser_actions_container.h
===================================================================
--- chrome/browser/views/browser_actions_container.h (revision 53742)
+++ chrome/browser/views/browser_actions_container.h (working copy)
@@ -68,10 +68,6 @@
// Returns the default icon, if any.
const SkBitmap& default_icon() const { return default_icon_; }
- // Overridden from views::View. Return a 0-inset so the icon can draw all the
- // way to the edge of the view if it wants.
- virtual gfx::Insets GetInsets() const;
-
// Overridden from views::ButtonListener:
virtual void ButtonPressed(views::Button* sender, const views::Event& event);
@@ -236,9 +232,9 @@
// visible icons. This can be triggered when the user finishes resizing the
// container or when Browser Actions are added/removed.
//
// We always animate from the current width (container_size_.width()) to the
// target size (animation_target_size_), using |resize_amount| to keep track of
// the animation progress.
//
// NOTE: When adding Browser Actions to a maximum width container (no overflow)
// we make sure to suppress the chevron menu if it wasn't visible. This is
@@ -248,15 +244,15 @@
//
////////////////////////////////////////////////////////////////////////////////
class BrowserActionsContainer
- : public views::View,
- public views::ViewMenuDelegate,
- public views::DragController,
- public views::ResizeArea::ResizeAreaDelegate,
- public AnimationDelegate,
- public ExtensionToolbarModel::Observer,
- public BrowserActionOverflowMenuController::Observer,
- public ExtensionContextMenuModel::PopupDelegate,
- public ExtensionPopup::Observer {
+ : public views::View,
+ public views::ViewMenuDelegate,
+ public views::DragController,
+ public views::ResizeArea::ResizeAreaDelegate,
+ public AnimationDelegate,
+ public ExtensionToolbarModel::Observer,
+ public BrowserActionOverflowMenuController::Observer,
+ public ExtensionContextMenuModel::PopupDelegate,
+ public ExtensionPopup::Observer {
public:
BrowserActionsContainer(Browser* browser, views::View* owner_view);
virtual ~BrowserActionsContainer();
@@ -460,8 +456,8 @@
// The model that tracks the order of the toolbar icons.
ExtensionToolbarModel* model_;
- // The current size of the container.
- gfx::Size container_size_;
+ // The current width of the container.
+ int container_width_;
// The resize area for the container.
views::ResizeArea* resize_area_;
« no previous file with comments | « no previous file | chrome/browser/views/browser_actions_container.cc » ('j') | chrome/browser/views/browser_actions_container.cc » ('J')
@@ -236,9 +232,9 @@
// container or when Browser Actions are added/removed.
//
-// We always animate from the current width (container_size_.width()) to the
-// target size (animation_target_size_), using |resize_amount| to keep track of
-// the animation progress.
+// We always animate from the current width (container_width_) to the target
+// size (animation_target_size_), using |resize_amount| to keep track of the
+// animation progress.
//
// NOTE: When adding Browser Actions to a maximum width container (no overflow)

Powered by Google App Engine
This is Rietveld 408576698